@@ -787,14 +787,14 @@ class Dataset:
         workbook = xlsxwriter.Workbook(filename, {'default_date_format':
                                                       'yyyy/mm/dd'})
         for table in self.sheets:
-            sheet = workbook.add_worksheet(table.name)
+            sheet: xlsxwriter.workbook.Worksheet = workbook.add_worksheet(table.name)
             pointer = Pointer(0, 0)
             for field in table.fields:
                 sheet.write(pointer.row, pointer.col, field, workbook.add_format(table.header_style.attr()))
                 pointer.next_col()
             pointer.next_row()
             for data_row in table.data_rows:
-                for col in sheet.fields:
+                for col in table.fields:
                     data = data_row[col]
                     if isinstance(data.value, datetime.date) \
                             or isinstance(data.value, datetime.time) \
